/v1/projects/{project_id}/dynamips/vms/{vm_id}/configs — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips vm »

# /v1/projects/{project_id}/dynamips/vms/{vm_id}/configs

Contents

- /v1/projects/{project_id}/dynamips/vms/{vm_id}/configs
  - GET /v1/projects/{project_id}/dynamips/vms/{vm_id}/configs
    - Response status codes
    - Output

## GET /v1/projects/{project_id}/dynamips/vms/{vm_id}/configs

Retrieve the startup and private configs content

### Response status codes

- 200: Configs retrieved
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
private_config_content | ✔ | ['string', 'null'] | Content of the private configuration file
startup_config_content | ✔ | ['string', 'null'] | Content of the startup configuration file

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Dynamips vm »